@@ -11,6 +11,7 @@ from area import area
 from collections import Counter
 from geographiclib.geodesic import Geodesic
 from pyproj import Transformer
+from scipy.spatial import KDTree
 from shapely import affinity
 from shapely.geometry import box, Polygon, LineString, MultiPolygon, GeometryCollection, Point, MultiPoint
 from shapely.ops import split, snap, unary_union
@@ -347,7 +348,7 @@ def find_self_intersection(line):
         intersection = MultiPoint(intersection)
     return intersection
 
-def convert_to_geojson_poly(feature, width = DEFAULT_WIDTH, verbose = False):
+def convert_to_geojson_poly(feature, width = DEFAULT_WIDTH, verbose = False, max_area = AREA_LIMIT):
   geom = feature.get('geometry', feature)
   t = geom['type']
   if t == 'LineString':
@@ -370,7 +371,7 @@ def convert_to_geojson_poly(feature, width = DEFAULT_WIDTH, verbose = False):
   elif t == 'Point':
     return geojson_point_to_poly(geom, width)
   elif t == 'Polygon' or t == 'MultiPolygon':
-    return chunk_by_area(feature, AREA_LIMIT, verbose)
+    return chunk_by_area(feature, max_area, verbose)
   elif t == 'GeometryCollection':
     polys = [convert_to_geojson_poly(p, width, verbose) for p in geom.get('geometries', [])]
     polys = flat_list(polys)
@@ -597,6 +598,27 @@ def subtract_geojson(
 
   return delta
 
+def prune_nearest_neighbors(frames, meters):
+  pts = []
+  for f in frames:
+    x, y = WGS_TO_MERCATOR.transform(
+      f.get('position').get('lon'),
+      f.get('position').get('lat'))
+    pts.append((x, y))
+  tree = KDTree(pts)
+  skip = set()
+  filtered_frames = []
+
+  for i, pt in enumerate(pts):
+    if i in skip:
+      continue;
+    filtered_frames.append(frames[i])
+    matches = tree.query_ball_point(pt, meters)
+    for match in matches:
+      skip.add(match)
+
+  return filtered_frames
+
 if __name__ == '__main__':
   parser = argparse.ArgumentParser()
   parser.add_argument('-s', '--shapefile', type=str, required=False)
